<?php

/**
 *  @file
 *  Create a AP Stream Wrapper class for the Media/Resource module.
 */

/**
 *  Create an instance like this:
 *  $ap = new MediaAPStreamWrapper('ap://[photo-code]');
 */
class MediaAPStreamWrapper extends MediaReadOnlyStreamWrapper {
  protected $base_url = '';
  protected $parameters = array('ap' => NULL);

  /**
   * Assign the base_url appropriately.
   */
  function __construct() {
    if (variable_get('media_ap_api_mode', 'production') == 'production') {
      $this->base_url = MEDIA_AP_REST_PROD;
    }
    else {
      $this->base_url = MEDIA_AP_REST_PREVIEW;
    }
  }

  function interpolateUrl() {
    $api_key = check_plain(variable_get('media_ap_api_key'));
    return $this->base_url . '/item/' . $this->getRawPhotoID() . '?apiKey=' . $api_key;
  }

  function getTarget($f) {
    return FALSE;
  }

  /**
   * Get the URL of an original image.
   */
  function getExternalUrl($size = 'full') {
    // This returns a URI, so to get the photo_id for media_ap_image_url() the
    // schema needs to be removed so all that remains is the bare ID.
    return media_ap_image_url($this->getRawPhotoID(), $size);
  }

  /**
   * Get the URL of the original thumbnail file.
   */
  function getOriginalThumbnailPath() {
    return $this->getExternalUrl('thumbnail');
  }

  function getLocalThumbnailPath() {
    $local_path = 'public://media-ap/' . $this->getRawPhotoID() . '.jpg';
    if (!file_exists($local_path)) {
      $dirname = drupal_dirname($local_path);
      file_prepare_directory($dirname, FILE_CREATE_DIRECTORY | FILE_MODIFY_PERMISSIONS);
      @copy($this->getOriginalThumbnailPath(), $local_path);
    }
    return $local_path;
  }

  static function getMimeType($uri, $mapping = NULL) {
    return 'image/jpeg';
  }

  /**
   * Return the raw photo ID.
   */
  function getRawPhotoID() {
    return str_replace('ap://', '', check_plain(media_ap_media_parse($this->uri)));
  }
}
