<?php

/**
 * @file
 */

/**
 * Implements hook_file_formatter_info().
 */
function media_ap_file_formatter_info() {
  $formatters['media_ap_image'] = array(
    'label' => t('AP Image'),
    'file types' => array('image'),
    'default settings' => array(
      'image_style' => '',
    ),
    'view callback' => 'media_ap_file_formatter_image_view',
    'settings callback' => 'media_ap_file_formatter_image_settings',
  );
  return $formatters;
}

/**
 * Implements hook_file_formatter_FORMATTER_view().
 */
function media_ap_file_formatter_image_view($file, $display, $langcode) {
  $scheme = file_uri_scheme($file->uri);
  if ($scheme == 'ap') {
    $wrapper = file_stream_wrapper_get_instance_by_uri($file->uri);
    $image_style = $display['settings']['image_style'];
    $valid_image_styles = image_style_options(FALSE);
    if (empty($image_style) || !isset($valid_image_styles[$image_style])) {
      $element = array(
        '#theme' => 'image',
        '#path' => $wrapper->getOriginalThumbnailPath(),
      );
    }
    else {
      $element = array(
        '#theme' => 'image_style',
        '#style_name' => $image_style,
        '#path' => $wrapper->getLocalThumbnailPath(),
      );
    }
    return $element;
  }
}

/**
 * Implements hook_file_formatter_FORMATTER_settings().
 */
function media_ap_file_formatter_image_settings($form, &$form_state, $settings) {
  $element = array();
  $element['image_style'] = array(
    '#title' => t('Image style'),
    '#type' => 'select',
    '#options' => image_style_options(FALSE),
    '#default_value' => $settings['image_style'],
    '#empty_option' => t('None (original image)'),
  );
  return $element;
}

/**
 * Implements hook_file_default_displays().
 */
function media_ap_file_default_displays() {
  $default_displays = array();

  // Default settings for displaying as a photo.
  $default_settings = array(
    'media_large' => array(
      'width' => 480,
      'height' => 360,
    ),
    'media_original' => array(
      'width' => 640,
      'height' => 480,
    ),
  );
  foreach ($default_settings as $view_mode => $settings) {
    $display_name = 'photo__' . $view_mode . '__media_ap_photo';
    $default_displays[$display_name] = (object) array(
      'api_version' => 1,
      'name' => $display_name,
      'status' => 1,
      'weight' => 1,
      'settings' => $settings,
    );
  }

  // Default settings for displaying a preview image. The higher weight ensures
  // that the display is used where possible.
  $default_image_styles = array(
    'media_preview' => 'square_thumbnail',
    'media_large' => 'large',
    'media_original' => ''
  );
  foreach ($default_image_styles as $view_mode => $image_style) {
    $display_name = 'photo__' . $view_mode . '__media_ap_image';
    $default_displays[$display_name] = (object) array(
      'api_version' => 1,
      'name' => $display_name,
      'status' => 1,
      'weight' => 2,
      'settings' => array('image_style' => $image_style),
    );
  }

  return $default_displays;
}

